part of masamune_purchase;

class MobilePurchaseAdapter
    extends PurchaseAdapter<MobilePurchaseProduct, MobilePurchaseOptions> {
  const MobilePurchaseAdapter({
    required this.products,
    this.onPrepare,
    this.onVerify,
    this.onSubscribe,
    this.onUnlock,
    this.onDeliver,
    this.onCheckSubscription,
    this.subscribeOptions = const SubscribeOptions(),
    this.autoConsumeOnAndroid = true,
    this.androidRefreshToken,
    this.userId,
    this.androidVerifierOptions = const AndroidVerifierOptions(),
    this.iosVerifierOptions = const IOSVerifierOptions(),
    this.deliverOptions = const DeliverOptions(),
  });

  final List<MobilePurchaseProduct> products;
  final Future<bool> Function()? onPrepare;
  final Future<bool> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onVerify;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onSubscribe;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onUnlock;
  final Future<void> Function(PurchaseDetails purchase,
      MobilePurchaseProduct product, PurchaseModel core)? onDeliver;
  final Future<void> Function(PurchaseModel core)? onCheckSubscription;
  final SubscribeOptions subscribeOptions;
  final bool autoConsumeOnAndroid;
  final String? androidRefreshToken;
  final String? userId;
  final AndroidVerifierOptions androidVerifierOptions;
  final IOSVerifierOptions iosVerifierOptions;
  final DeliverOptions deliverOptions;

  @override
  Future<void> initialize() async {
    await PurchaseCore.initialize(
      products: products,
      onPrepare: onPrepare,
      onVerify: onVerify,
      onSubscribe: onSubscribe,
      onUnlock: onUnlock,
      onDeliver: onDeliver,
      onCheckSubscription: onCheckSubscription,
      subscribeOptions: subscribeOptions,
      autoConsumeOnAndroid: autoConsumeOnAndroid,
      androidRefreshToken: androidRefreshToken,
      userId: userId,
      androidVerifierOptions: androidVerifierOptions,
      iosVerifierOptions: iosVerifierOptions,
      deliverOptions: deliverOptions,
    );
  }

  @override
  Future<void> purchase(
    BuildContext context,
    MobilePurchaseProduct product, {
    MobilePurchaseOptions? options,
  }) async {
    await PurchaseCore.purchase(
      product,
      applicationUserName: options?.applicationUserName,
      sandboxTesting: options?.sandboxTesting ?? false,
    );
  }

  @override
  Future<void> restore(BuildContext context) async {
    await PurchaseCore.restore();
  }

  @override
  Future<void> consume(
      BuildContext context, MobilePurchaseProduct product) async {
    await PurchaseCore.consume(product: product);
  }

  @override
  List<MobilePurchaseProduct> getRegisteredProducts() {
    return PurchaseCore.getProducts();
  }
}
